@@ -102,8 +102,8 @@ class GpmAction(deskbar.interfaces.Action):
     def __init__(self):
         deskbar.interfaces.Action.__init__(self, "")
         bus = dbus.Bus(dbus.Bus.TYPE_SESSION)
-        obj = bus.get_object('org.gnome.PowerManager', '/org/gnome/PowerManager')
-        self._gpm = dbus.Interface (obj, "org.gnome.PowerManager")
+        obj = bus.get_object('org.freedesktop.PowerManagement', '/org/freedesktop/PowerManagement')
+        self._gpm = dbus.Interface (obj, "org.freedesktop.PowerManagement")
         
 class SuspendAction(GpmAction):
     
@@ -168,6 +168,29 @@ class ShutdownAction(GpmAction):
     def get_verb(self):
         return _("Shutdown the machine")
     
+    
+class RebootAction(GpmAction):
+        
+    def __init__(self):
+        GpmAction.__init__(self)
+        
+    def activate(self, text=None):
+        prompt = LogoutPrompt(PROMPT_REBOOT, TIMEOUT)
+        response = prompt.run()
+        prompt.destroy()
+        
+        try:
+            if response == gtk.RESPONSE_OK:
+                self._gpm.Reboot()
+        except dbus.exceptions.DBusException:
+            # this will trigger a method timeout exception.
+            # As a workaround we swallow it silently
+            pass
+
+    def get_verb(self):
+        return _("Reboot the machine")
+     
+    
 class LockScreenAction(deskbar.interfaces.Action):
         
     def __init__(self):
@@ -195,7 +218,7 @@ class GpmMatch(deskbar.interfaces.Match):
 
 class SuspendMatch(GpmMatch):
     def __init__(self, **args):
-        GpmMatch.__init__(self, category="actions", icon="gpm-suspend-to-ram.png")
+        GpmMatch.__init__(self, icon="gpm-suspend-to-ram.png")
         self.add_action( SuspendAction() )
 
 class HibernateMatch(GpmMatch):
@@ -207,7 +230,12 @@ class ShutdownMatch(GpmMatch):
     def __init__(self, **args):
         GpmMatch.__init__(self, icon = "gnome-shutdown")
         self.add_action( ShutdownAction() )
-    
+
+class RebootMatch(GpmMatch):
+    def __init__(self, **args):
+        GpmMatch.__init__(self, icon = "gtk-refresh")
+        self.add_action( RebootAction() )
+        
 class LockScreenMatch(deskbar.interfaces.Match):
     def __init__(self, **args):
         deskbar.interfaces.Match.__init__(self, name=_("Lock"), icon = "system-lock-screen", **args)
@@ -301,7 +329,7 @@ class GdmRebootAction(GdmAction):
     
 class GdmRebootMatch(GdmMatch):
     def __init__(self, **args):
-        GdmMatch.__init__(self, name=_("Restart"), **args)
+        GdmMatch.__init__(self, name=_("Restart"), icon = "gtk-refresh", **args)
         self.add_action( GdmRebootAction(self.get_name()) )
     
 class GdmSwitchUserAction(GdmAction):    
@@ -354,14 +382,16 @@ class GdmHandler(deskbar.interfaces.Module):
     def init_gpm_matches(self):
         try:
             bus = dbus.Bus(dbus.Bus.TYPE_SESSION)
-            obj = bus.get_object('org.gnome.PowerManager', '/org/gnome/PowerManager')
-            gpm = dbus.Interface (obj, "org.gnome.PowerManager")
-            if gpm.canSuspend():
+            obj = bus.get_object('org.freedesktop.PowerManagement', '/org/freedesktop/PowerManagement')
+            gpm = dbus.Interface (obj, "org.freedesktop.PowerManagement")
+            if gpm.CanSuspend():
                 self.indexer.add(_("Suspend"), SuspendMatch())
-            if gpm.canHibernate():
+            if gpm.CanHibernate():
                 self.indexer.add(_("Hibernate"), HibernateMatch())
-            if gpm.canShutdown():
+            if gpm.CanShutdown():
                 self.indexer.add(_("Shutdown"), ShutdownMatch())
+            if gpm.CanReboot():
+                self.indexer.add(_("Reboot"), RebootMatch())
         except dbus.DBusException:
             return False
             
