@@ -1,4 +1,5 @@
-import gtk, gobject
+import gtk
+import glib
 
 class LingeringSelectionWindow (gtk.Window):
 	"""
@@ -50,7 +51,7 @@ class LingeringSelectionWindow (gtk.Window):
 		ox, oy = view.window.get_origin ()
 		area = view.get_background_area (path, column)
 		x, y = view.tree_to_widget_coords (area.x, area.y)
-		self.move (x + ox, y + oy)
+		self.move (x + ox, area.y + oy)
 		self.resize (area.width, area.height)
 		
 	def _linger (self):
@@ -58,7 +59,5 @@ class LingeringSelectionWindow (gtk.Window):
 		Display for a short while
 		"""
 		self.show_all ()
-		gobject.timeout_add (self.linger_time, self.hide)
-		
-		
+		glib.timeout_add (self.linger_time, self.hide)
 			
